duration property
The length of time this animation should last.
If reverseDuration is specified, then duration is only used when going
forward. Otherwise, it specifies the duration going in both directions.
Implementation
late Duration duration;
The length of time this animation should last.
If reverseDuration is specified, then duration is only used when going
forward. Otherwise, it specifies the duration going in both directions.
late Duration duration;