themeMode property
ThemeMode
themeMode
getter/setter pair
The current ThemeMode
Use isDarkTheme to check if the current theme is dark.
Implementation
late ThemeMode themeMode;
The current ThemeMode
Use isDarkTheme to check if the current theme is dark.
late ThemeMode themeMode;