forceBack<T extends Object> method
void
forceBack<T extends Object>([
- T? result
Navigate Back by popping the top-most page route with all pagesless route
associated with it and without calling onNavigateBack hook.
For example:
In case a Dialog (a Dialog is an example pageless route) is displayed and
we invoke forceBack, the dialog and the last page are popped from route stack.
Contrast this with the case when we call back where only the dialog is popped.
It is similar to _navigate.forceBack method.
Implementation
void forceBack<T extends Object>([T? result]) {
return _navigationBuilder.forceBack<T>(result);
}